__version__ = "0.6.12"
__git_commiter_name__ = "Arnon Yaari"
__git_commiter_email__ = "arnony@infinidat.com"
__git_branch__ = '(detached from v0.6.12)'
__git_remote_tracking_branch__ = '(No remote tracking)'
__git_remote_url__ = '(Not remote tracking)'
__git_head_hash__ = '0a3b05582d8e96954e3afc393e2937c38c4ae760'
__git_head_subject__ = 'Finished release v0.6.12.'
__git_head_message__ = ''
__git_dirty_diff__ = ''